@@ -1,5 +1,5 @@
 /* 
- * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2001 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -18,7 +18,8 @@
 
 #include <stdlib.h>
 #include <stdio.h>
-#include <sys/time.h>
+#include <sys/time.h>	/* for struct timeval */
+#include <time.h>	/* for CLOCKS_PER_SEC */
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
@@ -28,7 +29,7 @@
 #include <string.h>
 #include <signal.h>
 
-#include <linux/vt.h> 
+#include "Linux/vt.h" 
 #include <sys/ioctl.h>
 
 #include "dosemu_select.h"
