@@ -1,5 +1,5 @@
 /* 
- * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2001 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -50,6 +50,8 @@
 
 
 #include <string.h>
+#include <unistd.h>
+
 #include "config.h"
 
 #include "emu.h"
@@ -315,7 +317,23 @@ void tty_char_out(unsigned char ch, int s, int attr)
 /* i10_deb("tty_char_out: char 0x%02x, page %d, attr 0x%02x\n", ch, s, attr); */
 
   if (config.cardtype == CARD_NONE) {
+#if 1
+     /* FIXME
+      *
+      * For some unknown reasons (FILE *)stdout gets clobbered
+      * when we open a debug file (dbg_fd, -o/-O options on commandline)
+      * and even fputc(ch, stdout) then does not write anything.
+      * I could not find out _where_ this happens.
+      *
+      * However, writing directly to fd 1 still works. Therefore, because
+      * we do setbuf(stdout, NULL) anyway (src/base/init/init.c), we work
+      * around here this way.
+      *                         --Hans, 2001/04/27
+      */
+     write(1, &ch, 1);
+#else
      putchar (ch);
+#endif
      return;
   }
 
@@ -1583,16 +1601,19 @@ void int10_new()
 
 
     case 0x0c:		/* write pixel */
-      i10_msg("write pixel: NOT IMPLEMENTED\n");
+      if(vga.mode_class != TEXT)
+        vgaemu_put_pixel(LWORD(ecx), LWORD(edx), HI(bx), LO(ax));
       break;
 
 
     case 0x0d:		/* read pixel */
-      i10_msg("read pixel: NOT IMPLEMENTED\n");
       LO(ax) = 0;
+      if(vga.mode_class != TEXT) {
+        LO(ax) = vgaemu_get_pixel(LWORD(ecx), LWORD(edx), HI(bx));
+        i10_msg("read pixel: 0x%02x\n", LO(ax));
+      }
       break;
 
-
     case 0x0e:		/* print char */
       if(vga.mode_class == TEXT) {
         i10_deb(
