@@ -1,5 +1,5 @@
 /* 
- * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2001 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -23,7 +23,6 @@
 #include "keymaps.h"
 #include "memory.h"
 #include "bios.h"
-#include "kversion.h"
 #include "lpt.h"
 #include "int.h"
 
@@ -124,13 +123,16 @@ config_defaults(void)
       	break;
       case 5: case 586:
       case 6: case 686:
+      case 15:
         config.realcpu = CPU_586;
         config.pci = 1;	/* fair guess */
-        cpuflags = get_proc_string_by_key("flags");
+        cpuflags = get_proc_string_by_key("features");
+        if (!cpuflags) {
+          cpuflags = get_proc_string_by_key("flags");
+        }
         if (cpuflags && strstr(cpuflags, "tsc")) {
           /* bogospeed currently returns 0; should it deny
            * pentium features, fall back into 486 case */
-#if LX_KERNEL_VERSION > 2001126
 	  if ((kernel_version_code > 0x20100+126)
 	       && (cpuflags = get_proc_string_by_key("cpu MHz"))) {
 	    int di,df;
@@ -169,9 +171,6 @@ config_defaults(void)
 	  else
 	    cpuflags=0;
 	  if (!cpuflags) {
-#else
-	  if (1) {
-#endif
             if (!bogospeed(&config.cpu_spd, &config.cpu_tick_spd)) {
               break;
             }
@@ -281,7 +280,7 @@ config_defaults(void)
     config.realdelta = 9154;
 
     config.timers = 1;		/* deliver timer ints */
-    config.keybint = 1;		/* keyboard interrupts */
+    config.keybint = 1;		/* keyboard interrupts, now ALWAYS 1 */
  
     /* Lock file stuff */
     config.tty_lockdir = PATH_LOCKD;    /* The Lock directory  */
@@ -628,10 +627,97 @@ static void restore_usedoptions(char *usedoptions)
     char *p = getenv("DOSEMU_OPTIONS");
     if (p) {
         memset(usedoptions,0,256);
-        do usedoptions[(unsigned char)*p] = *p; while (*++p);
+        while (*p) {
+	    usedoptions[(unsigned char)*p] = *p;
+	    p++;
+	}
     }
 }
 
+static int find_option(char *option, int argc, char **argv)
+{
+  int i;
+  if (argc <=1 ) return 0;
+  for (i=1; i < argc; i++) {
+    if (!strcmp(argv[i], option)) {
+      return i;
+    }
+  }
+  return 0;
+}
+
+static int option_delete(int option, int *argc, char **argv)
+{
+  int i;
+  if (option >= *argc) return 0;
+  for (i=option; i < *argc; i++) {
+    argv[i] = argv[i+1];
+  }
+  *argc -= 1;
+  return option;
+}
+
+void secure_option_preparse(int *argc, char **argv)
+{
+  PRIV_SAVE_AREA
+  char *opt;
+  int runningsuid = get_orig_uid() != get_orig_euid();
+
+  char * get_option(char *key, int with_arg)
+  {
+    char *p;
+    int o = find_option(key, *argc, argv);
+    if (!o) return 0;
+    o = option_delete(o, argc, argv);
+    if (!with_arg) return "";
+    if (!with_arg || o >= *argc) return "";
+    if (argv[o][0] == '-') {
+      usage();
+      exit(0);
+    }
+    p = strdup(argv[o]);
+    option_delete(o, argc, argv);
+    return p;
+  }
+
+  if (runningsuid) unsetenv("DOSEMU_LAX_CHECKING");
+  else setenv("DOSEMU_LAX_CHECKING", "on", 1);
+
+  if (*argc <=1 ) return;
+  enter_priv_off();
+                                                  
+  opt = get_option("--Fusers", 1);
+  if (opt && opt[0]) {
+    if (runningsuid) {
+      fprintf(stderr, "Bypassing /etc/dosemu.users not allowed for suid-root\n");
+      exit(0);
+    }
+    DOSEMU_USERS_FILE = opt;
+  }
+
+  opt = get_option("--Flibdir", 1);
+  if (opt && opt[0]) {
+    if (runningsuid) {
+      fprintf(stderr, "Bypassing systemwide configuration not allowed for suid-root\n");
+      exit(0);
+    }
+    DOSEMU_LIB_DIR = opt;
+    DOSEMU_USERS_FILE = "none";
+  }
+
+  opt = get_option("--Fimagedir", 1);
+  if (opt && opt[0]) {
+    if (runningsuid) {
+      fprintf(stderr, "Bypassing systemwide boot path not allowed for suid-root\n");
+      exit(0);
+    }
+    DOSEMU_HDIMAGE_DIR = opt;
+  }
+
+  leave_priv_setting();
+}
+
+
 /*
  * DANG_BEGIN_FUNCTION config_init
  * 
@@ -886,8 +972,10 @@ config_init(int argc, char **argv)
 #endif
 	    break;
 	case 'K':
+#if 0 /* now dummy, leave it for compatibility */
 	    warn("Keyboard interrupt enabled...this is still buggy!\n");
 	    config.keybint = 1;
+#endif
 	    break;
 	case 'M':{
 		int             max_mem = config.vga ? 640 : MAX_MEM_SIZE;
@@ -1260,7 +1348,7 @@ usage(void)
 	"    -h dump configuration to stderr and exit (sets -D+c)\n"
 	"       0=no parser debug, 1=loop debug, 2=+if_else debug\n"
 	"    -H wait for dosdebug terminal at startup and pass dflags\n"
-	"    -K Do int9 (!#)\n"
+	"    -K no effect, left for compatibility\n"
 	"    -k use PC console keyboard (!)\n"
 	"    -M set memory size to SIZE kilobytes (!)\n"
 	"    -m enable mouse support (!#)\n"
