@@ -1,5 +1,5 @@
 /* 
- * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2001 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -19,21 +19,9 @@
 #include <string.h>
 #include <sys/ioctl.h>
 #ifdef __linux__
-  #include <linux/hdreg.h>
-  #include <linux/fd.h>
-  #include "kversion.h"
-  #if (LX_KERNEL_VERSION < 2003099)
-    #include <linux/fs.h>
-  #else
-    #if (GLIBC_VERSION_CODE >= 2000)
-      #include <sys/mount.h>
-    #else
-      #ifndef BLKGETSIZE
-			/* Note: _IO() being defined in <sys/ioctl.h> */
-        #define BLKGETSIZE _IO(0x12,96) /* return device size */
-      #endif
-    #endif
-  #endif
+  #include "Linux/hdreg.h"
+  #include "Linux/fd.h"
+  #include "Linux/fs.h"
 #endif
 #include <sys/stat.h>
 #include <sys/time.h>
@@ -129,7 +117,7 @@ static void dump_disk_blks(unsigned char *tb, int count, int ssiz)
  *
  *   |   adds up to 1 sector (512 bytes) of Master Boot Record (MBR)
  *       THIS IS KEPT IN MEMORY, and is the file 
- *       /var/lib/dosemu/partition.<partition>.
+ *       <DOSEMU_LIB_DIR>/partition.<partition>.
  *
  *   .   is any number of sectors before the desired partition start address.
  *       THESE SECTORS ARE NOT EMULATED, BUT MERELY SKIPPED
@@ -1220,8 +1208,8 @@ int13(u_char i)
     d_printf("disk get parameters %#x\n", disk);
 
     if (dp != NULL) {
-      /* get CMOS type */
-      switch (dp->sectors) {
+      /* get CMOS type for floppies*/
+      if (disk < 0x80) switch (dp->sectors) {
       case 9:
 	LO(bx) = THREE_INCH_720KFLOP;
 	break;
