@@ -1,6 +1,6 @@
 /* 
  * All modifications in this file to the original code are
- * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2001 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -25,7 +25,7 @@
  * Debug level.
  * 0 - normal / 1 - useful / 2 - too much
  */
-#define DEBUG_FATFS	0
+#define DEBUG_FATFS	2
 
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -625,7 +625,47 @@ void add_object(fatfs_t *f, unsigned parent, char *name)
   struct stat sb;
   obj_t tmp_o = {{0}, 0};
   unsigned u;
+  static int first = 1;
+  static int exxx = 0;
+  static char esys[16] = "";
+  static char ebat[16] = "";
 
+  if (first) {
+    first = 0;
+    if (config.emusys) {
+      snprintf(esys, 8+1+3+1,"config.%s", config.emusys);
+      esys[12] =0;
+      exxx += 2;
+    }
+    if (config.emubat) {
+      snprintf(ebat, 8+1+3+1,"autoexec.%s", config.emubat);
+      ebat[12] =0;
+      exxx += 2;
+    }
+  }
+
+  if (!parent && exxx) {
+    if (esys[0] && !strcmp(name, "config.sys")) {
+      fatfs_deb("add_object: ignored real %s in favour of %s\n", name, esys);
+      exxx -= 1;
+      return;
+    }
+    if (ebat[0] && !strcmp(name, "autoexec.bat")) {
+      fatfs_deb("add_object: ignored real %s in favour of %s\n", name, ebat);
+      exxx -= 1;
+      return;
+    }
+    if (esys[0] && !strcmp(name, esys)) {
+      tmp_o.is.faked_sys = 1;
+      fatfs_deb("add_object: faked %s as DOS entry CONFIG.SYS\n", esys);
+      exxx -= 1;
+    }
+    else if (ebat[0] && !strcmp(name, ebat)) {
+      tmp_o.is.faked_bat = 1;
+      fatfs_deb("add_object: faked %s as DOS entry AUTOEXEC.BAT\n", ebat);
+      exxx -= 1;
+    }
+  }
   if(!(strcmp(name, ".") && strcmp(name, ".."))) return;
 
   if(!(s = full_name(f, parent, name))) {
@@ -698,6 +738,8 @@ unsigned make_dos_entry(fatfs_t *f, obj_t *o, unsigned char **e)
   memset(dos_ent, 0, sizeof dos_ent);
 
   s = o->name;
+  if (o->is.faked_sys) s = "config.sys";
+  if (o->is.faked_bat) s = "autoexec.bat";
 
   if(o->is.this_dir) {
     s = ".";
