@@ -1,5 +1,5 @@
 /* 
- * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2001 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -25,6 +25,10 @@ void X_speaker_on(void *gp, unsigned ms, unsigned short period)
 
         /* Make the sound I want */
 	new_state.bell_pitch = speaker_period_to_Hz(period);  
+	/* Prohibit a crashing X server by not allowing to go higher than
+	 * 32767 kHz. Since the X server interpretes the pitch as a short int
+	 */
+	if (new_state.bell_pitch >= 0x8000) new_state.bell_pitch = 0x7fff;
 	new_state.bell_duration = ms;
 	XChangeKeyboardControl(display, KBBellDuration | KBBellPitch, &new_state);
 	
