@@ -1,6 +1,6 @@
 /* 
  * All modifications in this file to the original code are
- * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2001 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -42,7 +42,7 @@
   #define ENOMEDIUM       123     /* No medium found */
 #endif
 #ifdef __linux__
-#include <linux/cdrom.h>
+#include "Linux/cdrom.h"
 #endif
 
 #include "emu.h"
