@@ -1,6 +1,6 @@
 /* 
  * All modifications in this file to the original code are
- * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2001 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -25,9 +25,7 @@
 #if GLIBC_VERSION_CODE >= 2000
 #  include <netipx/ipx.h>
 #else
-#  include <linux/sockios.h>
-#  include <asm/types.h>
-#  include <linux/ipx.h>
+#  include "Linux/ipx.h"
 #endif /* GLIBC_VERSION_CODE */
 #include <netinet/in.h>
 #include <errno.h>
