@@ -1,5 +1,5 @@
 /* 
- * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2001 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -79,13 +79,12 @@ __asm__("___START___: jmp _emulate\n");
 #ifdef __linux__
 #if GLIBC_VERSION_CODE >= 2000
 #include <sys/vt.h>
-#include <sys/kd.h>
 #else
-#include <linux/vt.h>
-#include <linux/kd.h>
+#include "Linux/vt.h"
 #endif
-#include <linux/fd.h>
-#include <linux/hdreg.h>
+#include <sys/kd.h>
+#include "Linux/fd.h"
+#include "Linux/hdreg.h"
 #include <sys/vm86.h>
 #include <syscall.h>
 #endif
@@ -217,77 +216,6 @@ boot(void)
     ignore_segv--;
 }
 
-/* Silly Interrupt Generator Initialization/Closedown */
-
-#ifdef SIG
-SillyG_t       *SillyG = 0;
-static SillyG_t SillyG_[16 + 1];
-#endif
-
-/*
- * DANG_BEGIN_FUNCTION SIG_int
- * 
- * description: Allow DOSEMU to be made aware when a hard interrupt occurs
- * The IRQ numbers to monitor are taken from config.sillyint, each bit
- * corresponding to one IRQ. The higher 16 bit are defining the use of
- * SIGIO
- * 
- * DANG_END_FUNCTION
- */
-static inline void 
-SIG_init()
-{
-#if defined(SIG)
-    PRIV_SAVE_AREA
-    /* Get in touch with Silly Interrupt Handling */
-    if (config.sillyint) {
-	char            prio_table[] =
-	{8, 9, 10, 11, 12, 14, 15, 3, 4, 5, 6, 7};
-	int             i,
-	                irq;
-	SillyG_t       *sg = SillyG_;
-	for (i = 0; i < sizeof(prio_table); i++) {
-	    irq = prio_table[i];
-	    if (config.sillyint & (1 << irq)) {
-		int ret;
-		enter_priv_on();
-		ret = vm86_plus(VM86_REQUEST_IRQ, (SIGIO << 8) | irq);
-		leave_priv_setting();
-		if ( ret > 0) {
-		    g_printf("Gonna monitor the IRQ %d you requested\n", irq);
-		    sg->fd = -1;
-		    sg->irq = irq;
-		    g_printf("SIG: IRQ%d, enabling PIC-level %ld\n", irq, pic_irq_list[irq]);
-		    { extern int SillyG_do_irq(void);
-		    pic_seti(pic_irq_list[irq], SillyG_do_irq, 0);
-		    }
-		    pic_unmaski(pic_irq_list[irq]);
-		    sg++;
-		}
-	    }
-	}
-	sg->fd = 0;
-	if (sg != SillyG_)
-	    SillyG = SillyG_;
-    }
-#endif
-}
-
-static inline void 
-SIG_close()
-{
-#if defined(SIG)
-    if (SillyG) {
-	SillyG_t       *sg = SillyG;
-	while (sg->fd) {
-	    vm86_plus(VM86_FREE_IRQ, sg->irq);
-	    sg++;
-	}
-	g_printf("Closing all IRQ you opened!\n");
-    }
-#endif
-}
-
 static inline void 
 vm86plus_init(void)
 {
@@ -313,7 +241,6 @@ static inline void
 module_init(void)
 {
     vm86plus_init();		/* emumodule support */
-    SIG_init();			/* silly int generator support */
     memcheck_init();		/* lower 1M memory map support */
 }
 
@@ -324,7 +251,7 @@ static void do_liability_disclaimer_prompt(void)
   char buf[32];
   char disclaimer_file_name[256];
   static char text[] ="
-  The Linux DOSEMU, Copyright (C) 2000 the 'DOSEMU-Development-Team'.
+  The Linux DOSEMU, Copyright (C) 2001 the 'DOSEMU-Development-Team'.
   This program is  distributed  in  the  hope that it will be useful,
   but  WITHOUT  ANY  WARRANTY;   without even the implied warranty of
   MERCHANTABILITY  or  FITNESS FOR A PARTICULAR PURPOSE. See the file
@@ -386,6 +313,7 @@ emulate(int argc, char **argv)
 #endif
 {
     extern void parse_dosemu_users(void);
+    extern void secure_option_preparse(int *argc, char **argv);
     int e;
 
     srand(time(NULL));
@@ -403,6 +331,12 @@ emulate(int argc, char **argv)
     /* NOW! it is safe to touch the priv code.  */
     priv_init();  /* This must come first! */
 
+    /* Before we even try to give options to the parser,
+     * we pre-filter some dangerous options and delete them
+     * from the arguments list
+     */
+    secure_option_preparse(&argc, argv);
+
     /* This has to come next:
      * Parse dosemu.users _before_ any argument usage to catch
      * a not allowed user playing with overruns and kick him out
@@ -541,6 +475,7 @@ leavedos(int sig)
     struct sigaction sa;
     struct itimerval itv;
     extern int errno;
+    extern void SIG_close(); /* obsolete now; integrated into the kernel */
     extern void do_r3da_pending (void);	/* emuretrace stuff */
    
     if (leavedos_recurse_check)
@@ -611,6 +546,8 @@ leavedos(int sig)
 #if defined(X86_EMULATOR)
     /* if we are here with config.cpuemu>1 something went wrong... */
     if (config.cpuemu>1) {
+        extern void leave_cpu_emu(void);
+        
     	leave_cpu_emu();
     }
 #endif
