@@ -1,6 +1,6 @@
 /* 
  * All modifications in this file to the original code are
- * (C) Copyright 1992, ..., 2000 the "DOSEMU-Development-Team".
+ * (C) Copyright 1992, ..., 2001 the "DOSEMU-Development-Team".
  *
  * for details see file COPYING in the DOSEMU distribution
  */
@@ -101,8 +101,8 @@ struct mhpdbg_4bpar
     csip;
 };
 
-#define PAR4b_addr(x) ((char *)( ((long)mhpdbgc.bpload_par->##x##.seg << 4) \
-                        + mhpdbgc.bpload_par->##x##.off ))
+#define PAR4b_addr(x) ((char *)( ((long)mhpdbgc.bpload_par->x.seg << 4) \
+                        + mhpdbgc.bpload_par->x.off ))
 struct mhpdbgc
 {
    int stopped;
